export declare type JSONBaseNode = Readonly<{
    parent?: {
        key: number | string;
        node: JSONArrayNode | JSONObjectNode;
    };
}>;
export declare type JSONPrimitiveNode = Readonly<{
    type: "primitive";
    value: JSONPrimitiveType;
}> & JSONBaseNode;
export declare type JSONArrayNode = Readonly<{
    type: "array";
    items: JSONNode[];
}> & JSONBaseNode;
export declare type JSONObjectNode = Readonly<{
    type: "object";
    properties: Record<string, JSONNode>;
}> & JSONBaseNode;
export declare type JSONNode = JSONPrimitiveNode | JSONArrayNode | JSONObjectNode;
export declare type JSONPrimitiveType = string | boolean | number | null;
export declare type JSONArrayType = JSONType[];
export declare type JSONObjectType = {
    [property: string]: JSONType;
};
export declare type JSONType = JSONPrimitiveType | JSONArrayType | JSONObjectType;
export declare type KeywordValidator<T extends JSONType = JSONType> = (keyword: string, node: JSONObjectNode, value: T) => Error[] | Promise<Error[]>;
export declare type KeywordObjectReplacement = {
    type: "object";
    value: JSONType;
    level?: number;
};
export declare type KeywordKeywordReplacement = {
    type: "keyword";
    value: JSONObjectType;
};
export declare type KeywordReplacement = KeywordObjectReplacement | KeywordKeywordReplacement;
export declare type KeywordProcessor<T extends JSONType = JSONType> = (keyword: string, node: JSONObjectNode, value: T) => KeywordReplacement | Promise<KeywordReplacement>;
